@@ -382,6 +382,8 @@ def test_debian_build_compare():
     assert res
     res = utils.version_compare("4.9.110-3+deb9u4", 0, "*", None, "4.9.240-1")
     assert res
+    res = utils.version_compare("4.9.110-3+deb9u4", 0, "*", None, "4.9.110-1")
+    assert not res
 
 
 def test_debian_build_compare2():
@@ -426,6 +428,12 @@ def test_debian_build_compare3():
     assert res
     res = utils.version_compare("232-25+deb9u4", 0, "*", None, "249~rc2-1")
     assert res
+    res = utils.version_compare("232-25+deb9u4", 0, "*", None, "232-25+deb9u6")
+    assert res
+    res = utils.version_compare("232-25+deb9u4", 0, "*", None, "232-25+deb9u8")
+    assert res
+    res = utils.version_compare("2.50.3-2", 0, "*", None, "2.50.3-2+deb9u1")
+    assert res
 
 
 def test_parse_uri():
