@@ -86,6 +86,7 @@ class OSVSource(NvdSource):
             return ret_data
         cve_id = cve_data.get("id")
         cwe_id = ""
+        edition = "*"
         cve_references = cve_data.get("references", [])
         aliases = cve_data.get("aliases", [])
         aliases_block = ""
@@ -199,11 +200,12 @@ class OSVSource(NvdSource):
             if ":" in vendor and ("alpine" in vendor or "debian" in vendor):
                 tmpV = vendor.split(":")
                 vendor = tmpV[0].lower()
+                edition = f"{vendor}-{tmpV[1]}"
                 # Only use the precise version for debian
                 if "debian" in vendor:
-                    pkg_name_list = [f"{vendor}-{tmpV[1]}/{pkg_name}"]
+                    pkg_name_list = [f"{edition}/{pkg_name}"]
                 else:
-                    pkg_name_list.append(f"{vendor}-{tmpV[1]}/{pkg_name}")
+                    pkg_name_list.append(f"{edition}/{pkg_name}")
             # Substitute alpine for apk and debian for deb
             if vendor_overrides.get(vendor):
                 vendor = vendor_overrides.get(vendor)
@@ -262,6 +264,7 @@ class OSVSource(NvdSource):
                                 vendor=vendor,
                                 product=full_pkg,
                                 version="*",
+                                edition=edition,
                                 version_start_including=version_start_including,
                                 version_end_including=version_end_including,
                                 version_start_excluding=version_start_excluding,
